@@ -20,7 +20,7 @@ class MySocketServer:
         self.isconnected = False
         self.feeder = None
         self.laststarttime = datetime.now()
-        self.lastSeconds=0
+        self.lastseconds=0
         self.lastresetseconds=-1
 
     def setNewCarsFeeder(self,feeder):
@@ -34,10 +34,12 @@ class MySocketServer:
             nextfeedtime2 = self.laststarttime + timedelta(minutes = 5) 
 
             if timenow == nextfeedtime2 and self.feeder is not None:
-                #self.lastresetSeconds = self.lastSeconds #161
+                self.lastresetseconds = self.lastseconds #161
                 self.laststarttime = timenow
                 newcars,timeout,nextfeedtime = self.feeder.getCars(5)
                 cars.append(newcars)
+                print(f"Now serving {len(cars)} cars")
+                print(f"{newcars}")
 
             data = await reader.read(100)        
             message = data.decode("utf-8")
